instrumenttools.default_instrument_name_to_instrument_class
===========================================================

.. autofunction:: abjad.tools.instrumenttools.default_instrument_name_to_instrument_class.default_instrument_name_to_instrument_class
